@@ -1,10 +1,10 @@
 import os
 import tempfile
 import logging
+import enum
 from typing import Optional, Callable
 from designer_cmd.utils import PlatformVersion, get_1c_exe_path, execute_command, xml_conf_version_file_exists, \
-    clear_folder
-
+    clear_folder, port_in_use, get_1c_processes, kill_process
 
 logger = logging.getLogger(__name__)
 
@@ -149,7 +149,8 @@ class AbcExecutor:
     def get_executable_path(self) -> str:
         return get_1c_exe_path(self.platform_version)
 
-    def execute_command(self, mode: str, command_params: list, connection_params_required: bool = True):
+    def execute_command(self, mode: str, command_params: list,
+                        connection_params_required: bool = True, wait: bool = True):
         params = [mode]
         if connection_params_required:
             params += self.connection.get_connection_params()
@@ -164,7 +165,7 @@ class AbcExecutor:
 
         logger.debug(f'Выполняю команду {self.executable_path} {str_command}')
 
-        result = execute_command(self.executable_path, params, self.connection.timeout)
+        result = execute_command(self.executable_path, params, self.connection.timeout, wait)
 
         if result[0] != 0:
             try:
@@ -195,21 +196,52 @@ class AbcExecutor:
 
 class Enterprise(AbcExecutor):
 
-    def run_epf_erf(self, ep_x_path: str, c_string: str = None):
+    class RunMode(enum.Enum):
+        NORMAL = ''
+        MANAGER = '/TestManager'
+        CLIENT = '/TestClient'
+
+    def run_app(self, mode: Optional['RunMode'] = None, ep_x_path: Optional[str] = None,
+                c_string: Optional[str] = None, port: Optional[int]=None, wait: bool = True):
         """
-        Запускает обработку\отчет в базе
-        (соответствует команде /Execute )
-        :param ep_x_path: Путь к файлу cf, который необходимо сравнить с конфигурацией.
-        :param: c_string: Строка, которая будет переданна в /C.
+        Запускает экземпляр 1с предприятия
+        :param mode: режим запуска (Обычный, ТестКлиент, ТестМенеджер)
+        :param ep_x_path: Путь к файлу epf/epr, который необходимо запустить.
+        :param c_string: Строка, которая будет переданна в /C.
+        :param port: Порт на котором будет запущет тест менеджер
+        :param wait: Ожидать завершения.
         :return:
         """
-        logger.debug(f'Запускаю обработку {ep_x_path} в базе: {self.connection}')
-        params = [f'/Execute', ep_x_path]
-        if c_string:
-            params.append('/C')
-            params.append(c_string)
+        params = []
+        if ep_x_path:
+            logger.debug(f'Запускаю обработку {ep_x_path} в базе: {self.connection}')
+            params = [f'/Execute', ep_x_path]
+            if c_string:
+                params.append('/C')
+                params.append(c_string)
+        else:
+            logger.debug(f'Запускаю предприятние в режиме {mode} в базе: {self.connection}')
 
-        self.execute_command('ENTERPRISE ', params)
+        if mode:
+            params.append(mode.value)
+
+        if port:
+            if port_in_use(port):
+                raise SyntaxError('Порт уже занят')
+            params.append(f'-Tport {port}')
+
+        self.execute_command('ENTERPRISE ', params, wait=wait)
+
+    def kill_all_clients(self):
+        """
+        Завершает все запущенные под текущим соединением версии 1с
+        :return:
+        """
+        logger.debug(f'Останавливаю все экземпляры 1с, запущенные, на этом сервере по соединению {self.connection}')
+        procs_1c = get_1c_processes()
+        con_s = ' '.join(self.connection.get_connection_params())
+        for proc in filter(lambda x: con_s in x.cmd and 'ENTERPRISE' in x.cmd, procs_1c):
+            proc.kill()
 
 
 class Designer(AbcExecutor):
