@@ -4,8 +4,10 @@ from typing import Optional, List, Dict
 import unittest
 import os.path as path
 import os
-from designer_cmd.utils.utils import clear_folder
+from designer_cmd.utils.utils import clear_folder, kill_process
 from json import dump
+import socket
+import time
 
 
 class TestConnection(unittest.TestCase):
@@ -112,15 +114,29 @@ class TestEnterprise(DataPrepearer):
         with open(json_file, r'w') as f:
             dump({'text': text_data, 'file': file_path}, f)
 
-        self.enterprise.run_epf_erf(
-            self.epf_path,
-            json_file
+        self.enterprise.run_app(
+            ep_x_path=self.epf_path,
+            c_string=json_file
         )
         self.assertTrue(path.exists(file_path), 'Файл не создан!')
         with open(file_path, r'r', encoding='utf-8-sig') as f:
             lines = f.readlines()
             self.assertEqual(text_data, lines[0], 'Текст не соответствует ожиданию.')
 
+    def test_run_test_client(self):
+        port = 1578
+        self.enterprise.run_app(mode=self.enterprise.RunMode.CLIENT, port=port, wait=False)
+        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
+            self.assertTrue(s.connect_ex(('localhost', port)) == 0, 'Клиент запущен на неожиданном порту')
+
+    def test_run_test_manager(self):
+        self.enterprise.run_app(mode=self.enterprise.RunMode.MANAGER, wait=False)
+
+    def tearDown(self):
+        self.enterprise.kill_all_clients()
+        time.sleep(0.5)
+        super(TestEnterprise, self).tearDown()
+
 
 class TestDesigner(DataPrepearer):
 
@@ -438,7 +454,8 @@ class TestDesigner(DataPrepearer):
 class ExecutorMock(Rac):
 
     def __init__(self):
-        super(ExecutorMock, self).__init__('', None)
+        conn = RacConnection()
+        super(ExecutorMock, self).__init__('', conn)
         self.params = []
         self.mode = ''
         self.test_data = []
@@ -477,7 +494,7 @@ class TestInfobaseMod(unittest.TestCase):
         self.mock.base_id = base_id
         self.mod.deny_sessions(permission_code)
         self.assertEqual({'update', f'--cluster={self.cluster_id}', f'--infobase={base_id}',
-                          '--session-deny=on', f'--permission-code={permission_code}'}, set(self.mock.params),
+                          '--sessions-deny=on', f'--permission-code={permission_code}'}, set(self.mock.params),
                          'Сформированная команда не соответствует ожидаемой')
         self.assertEqual('infobase', self.mock.mode, 'Режим не соответствует ожидаемому')
 
